@@ -283,7 +283,7 @@ def main():
             installed = set(plugin.installed())
             plugin_want = want.get(plugin.id(), dict())
             if plugin.id() == "apt":
-                plugin_want.update({k: k for k in plugins["apt"].base_want()})
+                plugin_want.update({k: k for k in plugin.base_want()})
             add[plugin.id()] = [plugin_want[p] for p in plugin_want.keys() - installed]
             remove[plugin.id()] = installed - plugin_want.keys()
 
